import { EventEmitter, Component, Input, Output, ChangeDetectionStrategy, ChangeDetectorRef, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

class Core {
    constructor() {
        this.disabled = false;
        this.condition = false;
        this.loadComplete = new EventEmitter();
    }
    updateTools(tools) {
        this.question.tools = tools;
    }
    // Used for label colour
    getStyle() {
        // If question is not valid show error colour
        if (this.question !== undefined) {
            if (!this.question.valid) {
                return 'item-text-wrap text-danger';
            }
            else {
                return 'item-text-wrap';
            }
        }
    }
    disable(d) {
        if (d === undefined) {
            d = true;
        }
        this.disabled = d;
    }
    ngOnViewInit() {
        if (this.question.disabled != undefined) {
            this.disabled = this.question.disabled;
        }
    }
    // Check if is numeric
    isNumeric(n) {
        return !isNaN(parseFloat(n)) && isFinite(n);
    }
    isTool() {
        if (this.question !== undefined) {
            if (this.form !== undefined && this.form.complete) {
                return true;
            }
            else {
                if (this.question.isTool == true) {
                    return false;
                }
                else {
                    return true;
                }
            }
        }
    }
    hasTool() {
        if (this.question !== undefined) {
            if (this.form !== undefined && this.form.complete) {
                return true;
            }
            else {
                if (this.question.tool == true) {
                    return false;
                }
                else {
                    return true;
                }
            }
        }
        else {
            return true;
        }
    }
    hasDate() {
        return (this.Android() ||
            this.BlackBerry() ||
            this.iOS() ||
            this.Opera() ||
            this.Windows());
    }
    Android() {
        return navigator.userAgent.match(/Android/i);
    }
    BlackBerry() {
        return navigator.userAgent.match(/BlackBerry/i);
    }
    iOS() {
        return navigator.userAgent.match(/iPhone|iPad|iPod/i);
    }
    Opera() {
        return navigator.userAgent.match(/Opera Mini/i);
    }
    Windows() {
        return navigator.userAgent.match(/IEMobile/i);
    }
    Safari() {
        return navigator.userAgent.match(/Safari/i);
    }
    ngOnDestroy() {
        this.defaultValue = void 0;
        this.disabled = void 0;
        this.condition = void 0;
        this.form = void 0;
        this.smartForm = void 0;
        this._removeRef = void 0;
    }
}
Core.decorators = [
    { type: Component, args: [{
                selector: 'prop-base',
                template: '<div></div>'
            },] }
];
Core.ctorParameters = () => [];
Core.propDecorators = {
    question: [{ type: Input }],
    disabled: [{ type: Input }],
    condition: [{ type: Input }],
    loadComplete: [{ type: Output }]
};

class BodyComponent extends Core {
    constructor(ref) {
        super();
        this.ref = ref;
        this.color = 'dark';
        this.textChange = new EventEmitter();
    }
    getClass() {
        let obj = {};
        obj[this.color] = true;
        return obj;
    }
    // Setter for on change event
    setChangeEvent(value) {
        this.textChange.emit(value);
    }
    // Getter for on change event
    getChangeEvent() {
        return this.textChange;
    }
}
BodyComponent.decorators = [
    { type: Component, args: [{
                selector: 'prop-body',
                template: "<div rounded class=\"item-text-wrap borderless\" [ngClass]=\"getClass()\">\n    <h2 class=\"text-ps-white\" [innerHTML]=\"question?.tempLabel\"></h2>\n</div>\n",
                changeDetection: ChangeDetectionStrategy.OnPush
            },] }
];
BodyComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
BodyComponent.propDecorators = {
    question: [{ type: Input, args: ['value',] }],
    color: [{ type: Input, args: ['color',] }],
    textChange: [{ type: Output }]
};

class BodyModule {
}
BodyModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule],
                declarations: [BodyComponent],
                exports: [BodyComponent],
                entryComponents: [BodyComponent]
            },] }
];

/*
 * Public API Surface of propeller-components
 */

/**
 * Generated bundle index. Do not edit.
 */

export { BodyComponent, BodyModule, Core as ɵa };
//# sourceMappingURL=propeller-components.js.map
